Module common

Module common 

Self-contained modules used for miscellaneous purposes.

These are all candidates for being separated into different crates, tell me if functionality they provide is useful enough to do that.

Modules

ruler
Plugin manager with dependency resolution.
sourcemap
Tools to work with source positions and mapping.
utils
Random assortment of functions that’s used internally to write plugins.

Structs

TypeKey
std::any::TypeId and std::any::type_name fused into one struct.