RootExt

Trait RootExt 

pub trait RootExt:
    Debug
    + Downcast
    + Send
    + Sync { }
Extension set member for a block context.

Implementations

Source

impl dyn RootExt

pub fn is<__T: RootExt>(&self) -> bool

Returns true if the trait object wraps an object of type __T.

pub fn downcast<__T: RootExt>(self: Box<Self>) -> Result<Box<__T>, Box<Self>>

Returns a boxed object from a boxed trait object if the underlying object is of type __T. Returns the original boxed trait if it isn’t.

pub fn downcast_rc<__T: RootExt>(self: Rc<Self>) -> Result<Rc<__T>, Rc<Self>>

Returns an Rc-ed object from an Rc-ed trait object if the underlying object is of type __T. Returns the original Rc-ed trait if it isn’t.

pub fn downcast_ref<__T: RootExt>(&self) -> Option<&__T>

Returns a reference to the object within the trait object if it is of type __T, or None if it isn’t.

pub fn downcast_mut<__T: RootExt>(&mut self) -> Option<&mut __T>

Returns a mutable reference to the object within the trait object if it is of type __T, or None if it isn’t.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl RootExt for Vec<LinkifyPosition>

Implementors