pub fn set_theme(md: &mut MarkdownIt, theme: impl Into<String>)Expand description
Set the theme used for syntax highlighting.
The names should match one of returned by available_themes.
If not, it will panic.
pub fn set_theme(md: &mut MarkdownIt, theme: impl Into<String>)Set the theme used for syntax highlighting.
The names should match one of returned by available_themes.
If not, it will panic.